SystemOrganization addCategory: 'OrbeonBPMCore_Tests'!

TestCase subclass: #BpmExceptionCalendarTest
	instanceVariableNames: 'calendar'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMCore_Tests'!

!BpmExceptionCalendarTest methodsFor: 'Accessing' stamp: 'BrunoBB 02/02/2017 07:21'!
calendar
	^calendar! !

!BpmExceptionCalendarTest methodsFor: 'Updating' stamp: 'BrunoBB 02/02/2017 07:21'!
calendar: newValue
	calendar := newValue! !

!BpmExceptionCalendarTest methodsFor: 'other' stamp: 'BrunoBB 02/02/2017 07:21'!
setUp

	super setUp.

	calendar := BpmExceptionCalendar new.! !

!BpmExceptionCalendarTest methodsFor: 'other' stamp: 'BrunoBB 02/02/2017 07:25'!
testDuplicatedDays

	self assert: calendar hasExceptionDays not.
	self assert: calendar hasExceptionHours not.


	calendar addExceptionDay: Date today.
	calendar addExceptionDay: Date today.

	self assert: (calendar exceptionDaysSize = 1)! !

!BpmExceptionCalendarTest methodsFor: 'other' stamp: 'BrunoBB 02/02/2017 07:33'!
testIncludedDays

	self assert: calendar hasExceptionDays not.
	self assert: calendar hasExceptionHours not.

	calendar addExceptionDay: Date today.
	self assert: (calendar isExceptionDay: Date today).

	self deny: (calendar isExceptionDay: (Date fromString: '01/01/2017')).! !

!BpmExceptionCalendarTest methodsFor: 'other' stamp: 'BrunoBB 02/02/2017 08:30'!
testTimeIntervalAlreadyExist

	self assert: calendar hasExceptionDays not.
	self assert: calendar hasExceptionHours not.

	calendar addExceptionTimeFrom: (Time fromString: '6:00') to: (Time fromString: '8:00').
	calendar addExceptionTimeFrom: (Time fromString: '9:00') to: (Time fromString: '10:00').

	calendar addExceptionTimeFrom: (Time fromString: '12:00') to: (Time fromString: '14:00').
	calendar addExceptionTimeFrom: (Time fromString: '18:00') to: (Time fromString: '20:00').

	self deny: (calendar timeIntervalExistFrom: (Time fromString: '4:00') to: (Time fromString: '5:00')).
	self deny: (calendar timeIntervalExistFrom: (Time fromString: '15:00') to: (Time fromString: '16:00')).
	self deny: (calendar timeIntervalExistFrom: (Time fromString: '16:00') to: (Time fromString: '17:00')).
	self deny: (calendar timeIntervalExistFrom: (Time fromString: '21:00') to: (Time fromString: '22:00')).

	self assert: (calendar timeIntervalExistFrom: (Time fromString: '6:00') to: (Time fromString: '7:00')).
	self assert: (calendar timeIntervalExistFrom: (Time fromString: '9:30') to: (Time fromString: '9:40')).
	self assert: (calendar timeIntervalExistFrom: (Time fromString: '9:30') to: (Time fromString: '10:30')).
	self assert: (calendar timeIntervalExistFrom: (Time fromString: '11:00') to: (Time fromString: '12:30')).
	self assert: (calendar timeIntervalExistFrom: (Time fromString: '12:30') to: (Time fromString: '13:30')).
	self assert: (calendar timeIntervalExistFrom: (Time fromString: '12:30') to: (Time fromString: '15:00')).! !

TestCase subclass: #BpmExpectedExecutionTimeTest
	instanceVariableNames: 'expectedTime'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMCore_Tests'!

BpmExpectedExecutionTimeTest subclass: #BpmExpectedExecutionInDaysTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMCore_Tests'!

!BpmExpectedExecutionInDaysTest methodsFor: 'other' stamp: 'BrunoBB 02/03/2017 04:20'!
setUp
	| calendar |

	super setUp.

	expectedTime := BpmExpectedExecutionInDays new.

	calendar := expectedTime calendar.

	calendar addExceptionDay: (Date fromString: '01/01/2017').
	calendar addExceptionDay: (Date fromString: '01/02/2017').
	calendar addExceptionDay: (Date fromString: '03/01/2017').
	calendar addExceptionDay: (Date fromString: '02/02/2017').
	calendar addExceptionDay: (Date fromString: '03/03/2017').
	calendar addExceptionDay: (Date fromString: '04/04/2017').
	calendar addExceptionDay: (Date fromString: '05/05/2017').
	calendar addExceptionDay: (Date fromString: '06/06/2017').
	calendar addExceptionDay: (Date fromString: '07/07/2017').
	calendar addExceptionDay: (Date fromString: '08/08/2017').
	calendar addExceptionDay: (Date fromString: '09/09/2017').
	calendar addExceptionDay: (Date fromString: '10/10/2017').
	calendar addExceptionDay: (Date fromString: '10/10/2017').
	calendar addExceptionDay: (Date fromString: '11/11/2017').
	calendar addExceptionDay: (Date fromString: '12/12/2017').! !

!BpmExpectedExecutionInDaysTest methodsFor: 'other' stamp: 'BrunoBB 02/03/2017 04:26'!
testCaculateExecutionTime

	self assert: ((expectedTime calculateExecutionTimeFrom: (Date fromString: '01/01/2017') to: (Date fromString: '01/02/2017')) = 0).

	self assert: ((expectedTime calculateExecutionTimeFrom: (Date fromString: '01/01/2017') to: (Date fromString: '01/03/2017')) = 1).

	self assert: ((expectedTime calculateExecutionTimeFrom: (Date fromString: '01/01/2017') to: (Date fromString: '01/20/2017')) = 18).

	self assert: ((expectedTime calculateExecutionTimeFrom: (Date fromString: '01/01/2017') to: (Date fromString: '02/10/2017')) = 38).

	self assert: ((expectedTime calculateExecutionTimeFrom: (Date fromString: '01/01/2017') to: (Date fromString: '12/31/2017')) = 351).! !

BpmExpectedExecutionTimeTest subclass: #BpmExpectedExecutionInHoursTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMCore_Tests'!

!BpmExpectedExecutionInHoursTest methodsFor: 'other' stamp: 'BrunoBB 02/03/2017 06:12'!
setUp
	| calendar |

	super setUp.

	expectedTime := BpmExpectedExecutionInHours new.

	calendar := expectedTime calendar.

	calendar addExceptionTimeFrom: (Time fromString: '00:00') to: (Time fromString: '07:59').

	calendar addExceptionTimeFrom: (Time fromString: '18:01') to: (Time fromString: '23:59').! !

!BpmExpectedExecutionInHoursTest methodsFor: 'other' stamp: 'BrunoBB 02/03/2017 07:00'!
testCaculateExecutionTime

	self assert: ((expectedTime calculateExecutionTimeFrom: (TimeStamp fromString: '01/01/2017 08:00') to: (TimeStamp fromString: '01/01/2017 09:00')) = 1).
	self assert: ((expectedTime calculateExecutionTimeFrom: (TimeStamp fromString: '01/01/2017 08:00') to: (TimeStamp fromString: '01/01/2017 10:00')) = 2).
	self assert: ((expectedTime calculateExecutionTimeFrom: (TimeStamp fromString: '01/01/2017 08:00') to: (TimeStamp fromString: '01/01/2017 11:00')) = 3).
	self assert: ((expectedTime calculateExecutionTimeFrom: (TimeStamp fromString: '01/01/2017 08:00') to: (TimeStamp fromString: '01/01/2017 12:00')) = 4).

	self assert: ((expectedTime calculateExecutionTimeFrom: (TimeStamp fromString: '01/01/2017 06:00') to: (TimeStamp fromString: '01/01/2017 12:00')) = 4).

	self assert: ((expectedTime calculateExecutionTimeFrom: (TimeStamp fromString: '01/01/2017 05:00') to: (TimeStamp fromString: '01/01/2017 12:00')) = 4).
	self assert: ((expectedTime calculateExecutionTimeFrom: (TimeStamp fromString: '01/01/2017 05:00') to: (TimeStamp fromString: '01/01/2017 13:00')) = 5).
	self assert: ((expectedTime calculateExecutionTimeFrom: (TimeStamp fromString: '01/01/2017 05:00') to: (TimeStamp fromString: '01/01/2017 14:00')) = 6).
	self assert: ((expectedTime calculateExecutionTimeFrom: (TimeStamp fromString: '01/01/2017 05:00') to: (TimeStamp fromString: '01/01/2017 15:00')) = 7).
	self assert: ((expectedTime calculateExecutionTimeFrom: (TimeStamp fromString: '01/01/2017 05:00') to: (TimeStamp fromString: '01/01/2017 16:00')) = 8).
	self assert: ((expectedTime calculateExecutionTimeFrom: (TimeStamp fromString: '01/01/2017 05:00') to: (TimeStamp fromString: '01/01/2017 17:00')) = 9).
	self assert: ((expectedTime calculateExecutionTimeFrom: (TimeStamp fromString: '01/01/2017 05:00') to: (TimeStamp fromString: '01/01/2017 18:00')) = 10).
	self assert: ((expectedTime calculateExecutionTimeFrom: (TimeStamp fromString: '01/01/2017 05:00') to: (TimeStamp fromString: '01/01/2017 20:00')) = 10).

	self assert: ((expectedTime calculateExecutionTimeFrom: (TimeStamp fromString: '01/01/2017 07:30') to: (TimeStamp fromString: '01/01/2017 08:35')) = 1).! !

BpmExpectedExecutionTimeTest subclass: #BpmExpectedExecutionInMinutesTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMCore_Tests'!

!BpmExpectedExecutionInMinutesTest methodsFor: 'other' stamp: 'BrunoBB 02/03/2017 09:46'!
setUp
	| calendar |

	super setUp.

	expectedTime := BpmExpectedExecutionInMinutes new.

	calendar := expectedTime calendar.

	calendar addExceptionTimeFrom: (Time fromString: '00:00') to: (Time fromString: '07:59').

	calendar addExceptionTimeFrom: (Time fromString: '18:01') to: (Time fromString: '23:59').! !

!BpmExpectedExecutionInMinutesTest methodsFor: 'other' stamp: 'BrunoBB 02/03/2017 09:22'!
testCaculateExecutionTime

	self assert: ((expectedTime calculateExecutionTimeFrom: (TimeStamp fromString: '01/01/2017 08:00') to: (TimeStamp fromString: '01/01/2017 09:00')) = 60).
	self assert: ((expectedTime calculateExecutionTimeFrom: (TimeStamp fromString: '01/01/2017 08:00') to: (TimeStamp fromString: '01/01/2017 10:00')) = 120).
	self assert: ((expectedTime calculateExecutionTimeFrom: (TimeStamp fromString: '01/01/2017 08:00') to: (TimeStamp fromString: '01/01/2017 11:00')) = 180).
	self assert: ((expectedTime calculateExecutionTimeFrom: (TimeStamp fromString: '01/01/2017 08:00') to: (TimeStamp fromString: '01/01/2017 12:00')) = 240).

	self assert: ((expectedTime calculateExecutionTimeFrom: (TimeStamp fromString: '01/01/2017 06:00') to: (TimeStamp fromString: '01/01/2017 12:00')) = 240).

	self assert: ((expectedTime calculateExecutionTimeFrom: (TimeStamp fromString: '01/01/2017 05:00') to: (TimeStamp fromString: '01/01/2017 12:00')) = 240).
	self assert: ((expectedTime calculateExecutionTimeFrom: (TimeStamp fromString: '01/01/2017 05:00') to: (TimeStamp fromString: '01/01/2017 13:00')) = 300).
	self assert: ((expectedTime calculateExecutionTimeFrom: (TimeStamp fromString: '01/01/2017 05:00') to: (TimeStamp fromString: '01/01/2017 14:00')) = 360).
	self assert: ((expectedTime calculateExecutionTimeFrom: (TimeStamp fromString: '01/01/2017 05:00') to: (TimeStamp fromString: '01/01/2017 15:00')) = 420).
	self assert: ((expectedTime calculateExecutionTimeFrom: (TimeStamp fromString: '01/01/2017 05:00') to: (TimeStamp fromString: '01/01/2017 16:00')) = 480).
	self assert: ((expectedTime calculateExecutionTimeFrom: (TimeStamp fromString: '01/01/2017 05:00') to: (TimeStamp fromString: '01/01/2017 17:00')) = 540).
	self assert: ((expectedTime calculateExecutionTimeFrom: (TimeStamp fromString: '01/01/2017 05:00') to: (TimeStamp fromString: '01/01/2017 18:00')) = 600).
	self assert: ((expectedTime calculateExecutionTimeFrom: (TimeStamp fromString: '01/01/2017 05:00') to: (TimeStamp fromString: '01/01/2017 20:00')) = 600).

	self assert: ((expectedTime calculateExecutionTimeFrom: (TimeStamp fromString: '01/01/2017 07:30') to: (TimeStamp fromString: '01/01/2017 08:35')) = 35).! !

!BpmExpectedExecutionTimeTest methodsFor: 'Accessing' stamp: 'BrunoBB 02/03/2017 03:43'!
expectedTime
	^expectedTime! !

!BpmExpectedExecutionTimeTest methodsFor: 'Updating' stamp: 'BrunoBB 02/03/2017 03:43'!
expectedTime: newValue
	expectedTime := newValue! !

!BpmExpectedExecutionTimeTest methodsFor: 'other' stamp: 'BrunoBB 02/03/2017 03:48'!
setUp

	super setUp.

	expectedTime := BpmExpectedExecutionTime new.! !
